package trains.tests;

import static org.junit.Assert.*;

import java.io.StringReader;
import java.util.Collection;
import java.util.GregorianCalendar;
import java.util.Map;
import java.util.Set;

import org.junit.Before;
import org.junit.Test;

import trains.model.Station;
import trains.model.Time;
import trains.model.Train;

import trains.ui.MyController;

public class MyControllerTest {
  MyController myController;
	
	@Before
	public void setUp() throws Exception {
		
		String dati =
			"#TRAIN R3961,1234567\n" +
			"Bologna Centrale,9:28,9:36\n" +
			"Castel S.Pietro,11:05,11:07\n" +
			"Rimini,12:30,--:--\n" +
			"#ENDTRAIN\n" +
			"#TRAIN IR2069,12345--\n" +
			"Bologna Centrale,--:--,10:36\n" +
			"Castel S.Pietro,10:51,10:52\n" +
			"Rimini Miramare,12:30,--:--\n" +
			"#ENDTRAIN\n";

		CityStationsMock mock = new CityStationsMock();
		myController= new MyController(mock, new StringReader(dati));
		
	}

	@Test
	public void testGetSortedCitiess() {
		Set<String> cities=  myController.getSortedCities();
		assertEquals(3,cities.size());
		Object [] c = cities.toArray();
		String c1 = (String) c[0];
		assertTrue(c1.equalsIgnoreCase("Bologna"));
		c1 = (String) c[1];
		assertTrue(c1.equalsIgnoreCase("Castel S.Pietro"));
		c1 = (String) c[2];
		assertTrue(c1.equalsIgnoreCase("Rimini"));
		
		
		
	}

	@Test
	public void testSearchTrains() {
		
		GregorianCalendar cal = new GregorianCalendar();
		cal.set(GregorianCalendar.DAY_OF_WEEK, GregorianCalendar.SUNDAY);	
		Map<Train, Time> mappa = myController.searchTrains(new Station("Bologna", "Centrale"), new Station("Rimini", ""), cal.getTime());
		assertEquals(1,mappa.size());
		Set<Train> train = mappa.keySet();
		Object [] c = train.toArray();
		Train t= (Train) c[0];
		assertEquals("3961", t.getNumber());
		
		Collection<Time> coll = mappa.values();
		Object[] ti= coll.toArray();
		Time time= (Time) ti[0];
		assertEquals(2,time.getHours());
		assertEquals(54,time.getMinutes());
		
		mappa = myController.searchTrains(new Station("Bologna", "Centrale"), new Station("Rimini", "Miramare"), cal.getTime());
		assertEquals(0,mappa.size());
		mappa = myController.searchTrains(new Station("Bologna", "Centrale"), new Station("Castel S.Pietro", ""), cal.getTime());
		assertEquals(1,mappa.size());
		cal.set(GregorianCalendar.DAY_OF_WEEK, GregorianCalendar.MONDAY);
		mappa = myController.searchTrains(new Station("Bologna", "Centrale"), new Station("Castel S.Pietro", ""), cal.getTime());
		assertEquals(2,mappa.size());
		mappa = myController.searchTrains(new Station("Rimini", ""), new Station("Bologna", "Centrale"), cal.getTime());
		assertEquals(0,mappa.size());
		
	}

}
